# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.sqlquery.v1 import sqlquery_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2


class SqlQueryServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListSqlQuerys = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/ListSqlQuerys',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.ListSqlQuerysRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.ListSqlQuerysResponse.FromString,
                )
        self.CreateSqlQuery = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/CreateSqlQuery',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.CreateSqlQueryRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.CreateSqlQueryResponse.FromString,
                )
        self.GetSqlQuery = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/GetSqlQuery',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.GetSqlQueryRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.GetSqlQueryResponse.FromString,
                )
        self.UpdateSqlQuery = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/UpdateSqlQuery',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.UpdateSqlQueryRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.UpdateSqlQueryResponse.FromString,
                )
        self.DeleteSqlQuery = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/DeleteSqlQuery',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.DeleteSqlQueryRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.DeleteSqlQueryResponse.FromString,
                )
        self.RunSqlQuery = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/RunSqlQuery',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.RunSqlQueryRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.RunSqlQueryResponse.FromString,
                )


class SqlQueryServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListSqlQuerys(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSqlQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSqlQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateSqlQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSqlQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RunSqlQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SqlQueryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListSqlQuerys': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSqlQuerys,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.ListSqlQuerysRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.ListSqlQuerysResponse.SerializeToString,
            ),
            'CreateSqlQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSqlQuery,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.CreateSqlQueryRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.CreateSqlQueryResponse.SerializeToString,
            ),
            'GetSqlQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSqlQuery,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.GetSqlQueryRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.GetSqlQueryResponse.SerializeToString,
            ),
            'UpdateSqlQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateSqlQuery,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.UpdateSqlQueryRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.UpdateSqlQueryResponse.SerializeToString,
            ),
            'DeleteSqlQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSqlQuery,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.DeleteSqlQueryRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.DeleteSqlQueryResponse.SerializeToString,
            ),
            'RunSqlQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.RunSqlQuery,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.RunSqlQueryRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.RunSqlQueryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SqlQueryService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListSqlQuerys(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/ListSqlQuerys',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.ListSqlQuerysRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.ListSqlQuerysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSqlQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/CreateSqlQuery',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.CreateSqlQueryRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.CreateSqlQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSqlQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/GetSqlQuery',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.GetSqlQueryRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.GetSqlQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateSqlQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/UpdateSqlQuery',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.UpdateSqlQueryRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.UpdateSqlQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSqlQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/DeleteSqlQuery',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.DeleteSqlQueryRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.DeleteSqlQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RunSqlQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.sqlquery.v1.SqlQueryService/RunSqlQuery',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.RunSqlQueryRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_sqlquery_dot_v1_dot_sqlquery__pb2.RunSqlQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.datasource.v1 import datasource_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2


class DataSourceServiceStub(object):
    """EDA request/response

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataSources = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/ListDataSources',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.ListDataSourceRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.ListDataSourceResponse.FromString,
                )
        self.CreateDataSource = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/CreateDataSource',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.CreateDataSourceRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.CreateDataSourceResponse.FromString,
                )
        self.GetDataSource = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/GetDataSource',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetDataSourceRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetDataSourceResponse.FromString,
                )
        self.UpdateDataSource = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/UpdateDataSource',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.UpdateDataSourceRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.UpdateDataSourceResponse.FromString,
                )
        self.DeleteDataSource = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/DeleteDataSource',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.DeleteDataSourceRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.DeleteDataSourceResponse.FromString,
                )
        self.InferSchema = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/InferSchema',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.InferSchemaRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.InferSchemaResponse.FromString,
                )
        self.GetTableView = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/GetTableView',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetTableViewRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetTableViewResponse.FromString,
                )


class DataSourceServiceServicer(object):
    """EDA request/response

    """

    def ListDataSources(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InferSchema(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTableView(self, request, context):
        """get the table view from the data source. used to present table view.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataSourceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataSources': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataSources,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.ListDataSourceRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.ListDataSourceResponse.SerializeToString,
            ),
            'CreateDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataSource,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.CreateDataSourceRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.CreateDataSourceResponse.SerializeToString,
            ),
            'GetDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataSource,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetDataSourceRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetDataSourceResponse.SerializeToString,
            ),
            'UpdateDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataSource,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.UpdateDataSourceRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.UpdateDataSourceResponse.SerializeToString,
            ),
            'DeleteDataSource': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataSource,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.DeleteDataSourceRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.DeleteDataSourceResponse.SerializeToString,
            ),
            'InferSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.InferSchema,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.InferSchemaRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.InferSchemaResponse.SerializeToString,
            ),
            'GetTableView': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTableView,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetTableViewRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetTableViewResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataSourceService(object):
    """EDA request/response

    """

    @staticmethod
    def ListDataSources(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/ListDataSources',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.ListDataSourceRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.ListDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/CreateDataSource',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.CreateDataSourceRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.CreateDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/GetDataSource',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetDataSourceRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/UpdateDataSource',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.UpdateDataSourceRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.UpdateDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/DeleteDataSource',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.DeleteDataSourceRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.DeleteDataSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InferSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/InferSchema',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.InferSchemaRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.InferSchemaResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTableView(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.datasource.v1.DataSourceService/GetTableView',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetTableViewRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_datasource_dot_v1_dot_datasource__pb2.GetTableViewResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.featurehistogram.v1 import featurehistogram_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2


class FeatureHistogramServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListFeatureHistograms = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/ListFeatureHistograms',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.ListFeatureHistogramsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.ListFeatureHistogramsResponse.FromString,
                )
        self.CreateFeatureHistogram = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/CreateFeatureHistogram',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.CreateFeatureHistogramRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.CreateFeatureHistogramResponse.FromString,
                )
        self.GetFeatureHistogram = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/GetFeatureHistogram',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.GetFeatureHistogramRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.GetFeatureHistogramResponse.FromString,
                )
        self.UpdateFeatureHistogram = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/UpdateFeatureHistogram',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.UpdateFeatureHistogramRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.UpdateFeatureHistogramResponse.FromString,
                )
        self.DeleteFeatureHistogram = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/DeleteFeatureHistogram',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.DeleteFeatureHistogramRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.DeleteFeatureHistogramResponse.FromString,
                )


class FeatureHistogramServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListFeatureHistograms(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateFeatureHistogram(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFeatureHistogram(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateFeatureHistogram(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteFeatureHistogram(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FeatureHistogramServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListFeatureHistograms': grpc.unary_unary_rpc_method_handler(
                    servicer.ListFeatureHistograms,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.ListFeatureHistogramsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.ListFeatureHistogramsResponse.SerializeToString,
            ),
            'CreateFeatureHistogram': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateFeatureHistogram,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.CreateFeatureHistogramRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.CreateFeatureHistogramResponse.SerializeToString,
            ),
            'GetFeatureHistogram': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFeatureHistogram,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.GetFeatureHistogramRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.GetFeatureHistogramResponse.SerializeToString,
            ),
            'UpdateFeatureHistogram': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateFeatureHistogram,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.UpdateFeatureHistogramRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.UpdateFeatureHistogramResponse.SerializeToString,
            ),
            'DeleteFeatureHistogram': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteFeatureHistogram,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.DeleteFeatureHistogramRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.DeleteFeatureHistogramResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class FeatureHistogramService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListFeatureHistograms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/ListFeatureHistograms',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.ListFeatureHistogramsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.ListFeatureHistogramsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateFeatureHistogram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/CreateFeatureHistogram',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.CreateFeatureHistogramRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.CreateFeatureHistogramResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFeatureHistogram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/GetFeatureHistogram',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.GetFeatureHistogramRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.GetFeatureHistogramResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateFeatureHistogram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/UpdateFeatureHistogram',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.UpdateFeatureHistogramRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.UpdateFeatureHistogramResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteFeatureHistogram(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.featurehistogram.v1.FeatureHistogramService/DeleteFeatureHistogram',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.DeleteFeatureHistogramRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_featurehistogram_dot_v1_dot_featurehistogram__pb2.DeleteFeatureHistogramResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIgithub.com/metaprov/modelaapi/services/objectstored/v1/objectstored.proto\x12\x36github.com.metaprov.modelaapi.services.objectstored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"!\n\x0eIngestResponse\x12\x0f\n\x07liveKey\x18\x01 \x01(\t\"%\n\x0eObjectResponse\x12\x13\n\x0b\x61rchivePath\x18\x01 \x01(\t\"\xdb\x02\n\rObjectRequest\x12T\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12\x61\n\x06secret\x18\x06 \x03(\x0b\x32Q.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry\x12\x0b\n\x03key\x18\x07 \x01(\t\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"-\n\x1c\x45xistInVirtualBucketResponse\x12\r\n\x05\x65xist\x18\x01 \x01(\x08\x32\xa2\x05\n\x12ObjectstoreService\x12\x99\x01\n\x06Ingest\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\x9a\x01\n\x07\x41rchive\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\x9a\x01\n\x07Recover\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1a\x46.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse\"\x00\x12\xb5\x01\n\x14\x45xistInVirtualBucket\x12\x45.github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest\x1aT.github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse\"\x00\x42\x38Z6github.com/metaprov/modelaapi/services/objectstored/v1b\x06proto3')



_INGESTRESPONSE = DESCRIPTOR.message_types_by_name['IngestResponse']
_OBJECTRESPONSE = DESCRIPTOR.message_types_by_name['ObjectResponse']
_OBJECTREQUEST = DESCRIPTOR.message_types_by_name['ObjectRequest']
_OBJECTREQUEST_SECRETENTRY = _OBJECTREQUEST.nested_types_by_name['SecretEntry']
_EXISTINVIRTUALBUCKETRESPONSE = DESCRIPTOR.message_types_by_name['ExistInVirtualBucketResponse']
IngestResponse = _reflection.GeneratedProtocolMessageType('IngestResponse', (_message.Message,), {
  'DESCRIPTOR' : _INGESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.IngestResponse)
  })
_sym_db.RegisterMessage(IngestResponse)

ObjectResponse = _reflection.GeneratedProtocolMessageType('ObjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectResponse)
  })
_sym_db.RegisterMessage(ObjectResponse)

ObjectRequest = _reflection.GeneratedProtocolMessageType('ObjectRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _OBJECTREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _OBJECTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ObjectRequest)
  })
_sym_db.RegisterMessage(ObjectRequest)
_sym_db.RegisterMessage(ObjectRequest.SecretEntry)

ExistInVirtualBucketResponse = _reflection.GeneratedProtocolMessageType('ExistInVirtualBucketResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTINVIRTUALBUCKETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.objectstored.v1.objectstored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.objectstored.v1.ExistInVirtualBucketResponse)
  })
_sym_db.RegisterMessage(ExistInVirtualBucketResponse)

_OBJECTSTORESERVICE = DESCRIPTOR.services_by_name['ObjectstoreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/metaprov/modelaapi/services/objectstored/v1'
  _OBJECTREQUEST_SECRETENTRY._options = None
  _OBJECTREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _INGESTRESPONSE._serialized_start=204
  _INGESTRESPONSE._serialized_end=237
  _OBJECTRESPONSE._serialized_start=239
  _OBJECTRESPONSE._serialized_end=276
  _OBJECTREQUEST._serialized_start=279
  _OBJECTREQUEST._serialized_end=626
  _OBJECTREQUEST_SECRETENTRY._serialized_start=581
  _OBJECTREQUEST_SECRETENTRY._serialized_end=626
  _EXISTINVIRTUALBUCKETRESPONSE._serialized_start=628
  _EXISTINVIRTUALBUCKETRESPONSE._serialized_end=673
  _OBJECTSTORESERVICE._serialized_start=676
  _OBJECTSTORESERVICE._serialized_end=1350
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.webrequestrun.v1 import webrequestrun_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2


class WebRequestRunServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListWebRequestRuns = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/ListWebRequestRuns',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsResponse.FromString,
                )
        self.CreateWebRequestRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/CreateWebRequestRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunResponse.FromString,
                )
        self.GetWebRequestRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/GetWebRequestRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunResponse.FromString,
                )
        self.UpdateWebRequestRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/UpdateWebRequestRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunResponse.FromString,
                )
        self.DeleteWebRequestRun = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/DeleteWebRequestRun',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunResponse.FromString,
                )


class WebRequestRunServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListWebRequestRuns(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateWebRequestRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWebRequestRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateWebRequestRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteWebRequestRun(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_WebRequestRunServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListWebRequestRuns': grpc.unary_unary_rpc_method_handler(
                    servicer.ListWebRequestRuns,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsResponse.SerializeToString,
            ),
            'CreateWebRequestRun': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateWebRequestRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunResponse.SerializeToString,
            ),
            'GetWebRequestRun': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWebRequestRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunResponse.SerializeToString,
            ),
            'UpdateWebRequestRun': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateWebRequestRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunResponse.SerializeToString,
            ),
            'DeleteWebRequestRun': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteWebRequestRun,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class WebRequestRunService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListWebRequestRuns(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/ListWebRequestRuns',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.ListWebRequestRunsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateWebRequestRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/CreateWebRequestRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.CreateWebRequestRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWebRequestRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/GetWebRequestRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.GetWebRequestRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateWebRequestRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/UpdateWebRequestRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.UpdateWebRequestRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteWebRequestRun(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.webrequestrun.v1.WebRequestRunService/DeleteWebRequestRun',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_webrequestrun_dot_v1_dot_webrequestrun__pb2.DeleteWebRequestRunResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/catalog/v1/catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_catalog_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/catalog/v1/catalog.proto\x12\x31github.com.metaprov.modelaapi.services.catalog.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aGgithub.com/metaprov/modelaapi/pkg/apis/catalog/v1alpha1/generated.proto\"\xbf\x01\n\x15ListAlgorithmsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n\x16ListAlgorithmsResponse\x12Z\n\nalgorithms\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.AlgorithmList\"6\n\x13GetAlgorithmRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"m\n\x14GetAlgorithmResponse\x12U\n\talgorithm\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Algorithm\"\xc5\x01\n\x18ListManagedimagesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.catalog.v1.ListManagedimagesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\x19ListManagedimagesResponse\x12`\n\rmanagedImages\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ManagedImageList\"9\n\x16GetManagedimageRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"u\n\x17GetManagedimageResponse\x12Z\n\x0bmanagedItem\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.ManagedImage\"\xc3\x01\n\x17ListMLFrameworksRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x66\n\x06labels\x18\x02 \x03(\x0b\x32V.github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"z\n\x18ListMLFrameworksResponse\x12^\n\x0cmlframeworks\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFrameworkList\"8\n\x15GetMLFrameworkRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"s\n\x16GetMLFrameworkResponse\x12Y\n\x0bmlframework\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.MLFramework\"\xb7\x01\n\x11ListCloudsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x02 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"h\n\x12ListCloudsResponse\x12R\n\x06\x63louds\x18\x01 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.CloudList\"2\n\x0fGetCloudRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x10GetCloudResponse\x12M\n\x05\x63loud\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.Cloud\"\xc7\x01\n\x19ListPublicDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12h\n\x06labels\x18\x02 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\x1aListPublicDatasetsResponse\x12\x62\n\x0epublicDatasets\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDatasetList\":\n\x17GetPublicDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"y\n\x18GetPublicDatasetResponse\x12]\n\rpublicDataset\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PublicDataset\"?\n\x1c\x44ownloadPublicDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\",\n\x1d\x44ownloadPublicDatasetResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\">\n\x1bPreviewPublicDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"+\n\x1cPreviewPublicDatasetResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"N\n\x1b\x41pplyPublicDatasetCRRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06\x63rname\x18\x03 \x01(\t\"+\n\x1c\x41pplyPublicDatasetCRResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"\xcb\x01\n\x1bListPretrainedModelsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12j\n\x06labels\x18\x02 \x03(\x0b\x32Z.github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x1cListPretrainedModelsResponse\x12\x66\n\x10pretrainedModels\x18\x01 \x01(\x0b\x32L.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModelList\"<\n\x19GetPretrainedModelRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x7f\n\x1aGetPretrainedModelResponse\x12\x61\n\x0fpretrainedModel\x18\x01 \x01(\x0b\x32H.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.PretrainedModel\"\xc9\x01\n\x1aListWorkloadClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12i\n\x06labels\x18\x02 \x03(\x0b\x32Y.github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x1bListWorkloadClassesResponse\x12]\n\tworkloads\x18\x01 \x01(\x0b\x32J.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClassList\":\n\x17GetWorkloadClassRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\"t\n\x18GetWorkloadClassResponse\x12X\n\x08workload\x18\x01 \x01(\x0b\x32\x46.github.com.metaprov.modelaapi.pkg.apis.catalog.v1alpha1.WorkloadClass2\x92\x18\n\x0e\x43\x61talogService\x12\xbc\x01\n\rListAlgorithm\x12H.github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest\x1aI.github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1/algorithms\x12\xbe\x01\n\x0cGetAlgorithm\x12\x46.github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmRequest\x1aG.github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1/algorithms/{name}\x12\xc9\x01\n\x11ListManagedImages\x12K.github.com.metaprov.modelaapi.services.catalog.v1.ListManagedimagesRequest\x1aL.github.com.metaprov.modelaapi.services.catalog.v1.ListManagedimagesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/managedimages\x12\xca\x01\n\x0fGetManagedImage\x12I.github.com.metaprov.modelaapi.services.catalog.v1.GetManagedimageRequest\x1aJ.github.com.metaprov.modelaapi.services.catalog.v1.GetManagedimageResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/managedimages/{name}\x12\xc5\x01\n\x10ListMLFrameworks\x12J.github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest\x1aK.github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/mlframeworks\x12\xc6\x01\n\x0eGetMLFramework\x12H.github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkRequest\x1aI.github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/mlframeworks/{name}\x12\xad\x01\n\nListClouds\x12\x44.github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest\x1a\x45.github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsResponse\"\x12\x82\xd3\xe4\x93\x02\x0c\x12\n/v1/clouds\x12\xae\x01\n\x08GetCloud\x12\x42.github.com.metaprov.modelaapi.services.catalog.v1.GetCloudRequest\x1a\x43.github.com.metaprov.modelaapi.services.catalog.v1.GetCloudResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/clouds/{name}\x12\xd1\x01\n\x13ListWorkloadClasses\x12M.github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest\x1aN.github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/workloadclasses\x12\xcf\x01\n\x10GetWorkloadClass\x12J.github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassRequest\x1aK.github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/workloadclasses/{name}\x12\xcc\x01\n\x11ListPublicDataset\x12L.github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest\x1aM.github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/publicdatasets\x12\xce\x01\n\x10GetPublicDataset\x12J.github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetRequest\x1aK.github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/publicdatasets/{name}\x12\xe6\x01\n\x15\x44ownloadPublicDataset\x12O.github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetRequest\x1aP.github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/publicdatasets/{name}:download\x12\xe2\x01\n\x14PreviewPublicDataset\x12N.github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetRequest\x1aO.github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1/publicdatasets/{name}:preview\x12\xe0\x01\n\x14\x41pplyPublicDatasetCR\x12N.github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRRequest\x1aO.github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/publicdatasets/{name}:applyB3Z1github.com/metaprov/modelaapi/services/catalog/v1b\x06proto3')



_LISTALGORITHMSREQUEST = DESCRIPTOR.message_types_by_name['ListAlgorithmsRequest']
_LISTALGORITHMSREQUEST_LABELSENTRY = _LISTALGORITHMSREQUEST.nested_types_by_name['LabelsEntry']
_LISTALGORITHMSRESPONSE = DESCRIPTOR.message_types_by_name['ListAlgorithmsResponse']
_GETALGORITHMREQUEST = DESCRIPTOR.message_types_by_name['GetAlgorithmRequest']
_GETALGORITHMRESPONSE = DESCRIPTOR.message_types_by_name['GetAlgorithmResponse']
_LISTMANAGEDIMAGESREQUEST = DESCRIPTOR.message_types_by_name['ListManagedimagesRequest']
_LISTMANAGEDIMAGESREQUEST_LABELSENTRY = _LISTMANAGEDIMAGESREQUEST.nested_types_by_name['LabelsEntry']
_LISTMANAGEDIMAGESRESPONSE = DESCRIPTOR.message_types_by_name['ListManagedimagesResponse']
_GETMANAGEDIMAGEREQUEST = DESCRIPTOR.message_types_by_name['GetManagedimageRequest']
_GETMANAGEDIMAGERESPONSE = DESCRIPTOR.message_types_by_name['GetManagedimageResponse']
_LISTMLFRAMEWORKSREQUEST = DESCRIPTOR.message_types_by_name['ListMLFrameworksRequest']
_LISTMLFRAMEWORKSREQUEST_LABELSENTRY = _LISTMLFRAMEWORKSREQUEST.nested_types_by_name['LabelsEntry']
_LISTMLFRAMEWORKSRESPONSE = DESCRIPTOR.message_types_by_name['ListMLFrameworksResponse']
_GETMLFRAMEWORKREQUEST = DESCRIPTOR.message_types_by_name['GetMLFrameworkRequest']
_GETMLFRAMEWORKRESPONSE = DESCRIPTOR.message_types_by_name['GetMLFrameworkResponse']
_LISTCLOUDSREQUEST = DESCRIPTOR.message_types_by_name['ListCloudsRequest']
_LISTCLOUDSREQUEST_LABELSENTRY = _LISTCLOUDSREQUEST.nested_types_by_name['LabelsEntry']
_LISTCLOUDSRESPONSE = DESCRIPTOR.message_types_by_name['ListCloudsResponse']
_GETCLOUDREQUEST = DESCRIPTOR.message_types_by_name['GetCloudRequest']
_GETCLOUDRESPONSE = DESCRIPTOR.message_types_by_name['GetCloudResponse']
_LISTPUBLICDATASETSREQUEST = DESCRIPTOR.message_types_by_name['ListPublicDatasetsRequest']
_LISTPUBLICDATASETSREQUEST_LABELSENTRY = _LISTPUBLICDATASETSREQUEST.nested_types_by_name['LabelsEntry']
_LISTPUBLICDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['ListPublicDatasetsResponse']
_GETPUBLICDATASETREQUEST = DESCRIPTOR.message_types_by_name['GetPublicDatasetRequest']
_GETPUBLICDATASETRESPONSE = DESCRIPTOR.message_types_by_name['GetPublicDatasetResponse']
_DOWNLOADPUBLICDATASETREQUEST = DESCRIPTOR.message_types_by_name['DownloadPublicDatasetRequest']
_DOWNLOADPUBLICDATASETRESPONSE = DESCRIPTOR.message_types_by_name['DownloadPublicDatasetResponse']
_PREVIEWPUBLICDATASETREQUEST = DESCRIPTOR.message_types_by_name['PreviewPublicDatasetRequest']
_PREVIEWPUBLICDATASETRESPONSE = DESCRIPTOR.message_types_by_name['PreviewPublicDatasetResponse']
_APPLYPUBLICDATASETCRREQUEST = DESCRIPTOR.message_types_by_name['ApplyPublicDatasetCRRequest']
_APPLYPUBLICDATASETCRRESPONSE = DESCRIPTOR.message_types_by_name['ApplyPublicDatasetCRResponse']
_LISTPRETRAINEDMODELSREQUEST = DESCRIPTOR.message_types_by_name['ListPretrainedModelsRequest']
_LISTPRETRAINEDMODELSREQUEST_LABELSENTRY = _LISTPRETRAINEDMODELSREQUEST.nested_types_by_name['LabelsEntry']
_LISTPRETRAINEDMODELSRESPONSE = DESCRIPTOR.message_types_by_name['ListPretrainedModelsResponse']
_GETPRETRAINEDMODELREQUEST = DESCRIPTOR.message_types_by_name['GetPretrainedModelRequest']
_GETPRETRAINEDMODELRESPONSE = DESCRIPTOR.message_types_by_name['GetPretrainedModelResponse']
_LISTWORKLOADCLASSESREQUEST = DESCRIPTOR.message_types_by_name['ListWorkloadClassesRequest']
_LISTWORKLOADCLASSESREQUEST_LABELSENTRY = _LISTWORKLOADCLASSESREQUEST.nested_types_by_name['LabelsEntry']
_LISTWORKLOADCLASSESRESPONSE = DESCRIPTOR.message_types_by_name['ListWorkloadClassesResponse']
_GETWORKLOADCLASSREQUEST = DESCRIPTOR.message_types_by_name['GetWorkloadClassRequest']
_GETWORKLOADCLASSRESPONSE = DESCRIPTOR.message_types_by_name['GetWorkloadClassResponse']
ListAlgorithmsRequest = _reflection.GeneratedProtocolMessageType('ListAlgorithmsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTALGORITHMSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTALGORITHMSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsRequest)
  })
_sym_db.RegisterMessage(ListAlgorithmsRequest)
_sym_db.RegisterMessage(ListAlgorithmsRequest.LabelsEntry)

ListAlgorithmsResponse = _reflection.GeneratedProtocolMessageType('ListAlgorithmsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALGORITHMSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListAlgorithmsResponse)
  })
_sym_db.RegisterMessage(ListAlgorithmsResponse)

GetAlgorithmRequest = _reflection.GeneratedProtocolMessageType('GetAlgorithmRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmRequest)
  })
_sym_db.RegisterMessage(GetAlgorithmRequest)

GetAlgorithmResponse = _reflection.GeneratedProtocolMessageType('GetAlgorithmResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetAlgorithmResponse)
  })
_sym_db.RegisterMessage(GetAlgorithmResponse)

ListManagedimagesRequest = _reflection.GeneratedProtocolMessageType('ListManagedimagesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMANAGEDIMAGESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListManagedimagesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMANAGEDIMAGESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListManagedimagesRequest)
  })
_sym_db.RegisterMessage(ListManagedimagesRequest)
_sym_db.RegisterMessage(ListManagedimagesRequest.LabelsEntry)

ListManagedimagesResponse = _reflection.GeneratedProtocolMessageType('ListManagedimagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMANAGEDIMAGESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListManagedimagesResponse)
  })
_sym_db.RegisterMessage(ListManagedimagesResponse)

GetManagedimageRequest = _reflection.GeneratedProtocolMessageType('GetManagedimageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMANAGEDIMAGEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetManagedimageRequest)
  })
_sym_db.RegisterMessage(GetManagedimageRequest)

GetManagedimageResponse = _reflection.GeneratedProtocolMessageType('GetManagedimageResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMANAGEDIMAGERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetManagedimageResponse)
  })
_sym_db.RegisterMessage(GetManagedimageResponse)

ListMLFrameworksRequest = _reflection.GeneratedProtocolMessageType('ListMLFrameworksRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTMLFRAMEWORKSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTMLFRAMEWORKSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksRequest)
  })
_sym_db.RegisterMessage(ListMLFrameworksRequest)
_sym_db.RegisterMessage(ListMLFrameworksRequest.LabelsEntry)

ListMLFrameworksResponse = _reflection.GeneratedProtocolMessageType('ListMLFrameworksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMLFRAMEWORKSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListMLFrameworksResponse)
  })
_sym_db.RegisterMessage(ListMLFrameworksResponse)

GetMLFrameworkRequest = _reflection.GeneratedProtocolMessageType('GetMLFrameworkRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMLFRAMEWORKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkRequest)
  })
_sym_db.RegisterMessage(GetMLFrameworkRequest)

GetMLFrameworkResponse = _reflection.GeneratedProtocolMessageType('GetMLFrameworkResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMLFRAMEWORKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetMLFrameworkResponse)
  })
_sym_db.RegisterMessage(GetMLFrameworkResponse)

ListCloudsRequest = _reflection.GeneratedProtocolMessageType('ListCloudsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTCLOUDSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTCLOUDSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsRequest)
  })
_sym_db.RegisterMessage(ListCloudsRequest)
_sym_db.RegisterMessage(ListCloudsRequest.LabelsEntry)

ListCloudsResponse = _reflection.GeneratedProtocolMessageType('ListCloudsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTCLOUDSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListCloudsResponse)
  })
_sym_db.RegisterMessage(ListCloudsResponse)

GetCloudRequest = _reflection.GeneratedProtocolMessageType('GetCloudRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetCloudRequest)
  })
_sym_db.RegisterMessage(GetCloudRequest)

GetCloudResponse = _reflection.GeneratedProtocolMessageType('GetCloudResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetCloudResponse)
  })
_sym_db.RegisterMessage(GetCloudResponse)

ListPublicDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListPublicDatasetsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPUBLICDATASETSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPUBLICDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsRequest)
  })
_sym_db.RegisterMessage(ListPublicDatasetsRequest)
_sym_db.RegisterMessage(ListPublicDatasetsRequest.LabelsEntry)

ListPublicDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListPublicDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPUBLICDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPublicDatasetsResponse)
  })
_sym_db.RegisterMessage(ListPublicDatasetsResponse)

GetPublicDatasetRequest = _reflection.GeneratedProtocolMessageType('GetPublicDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetRequest)
  })
_sym_db.RegisterMessage(GetPublicDatasetRequest)

GetPublicDatasetResponse = _reflection.GeneratedProtocolMessageType('GetPublicDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPUBLICDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetPublicDatasetResponse)
  })
_sym_db.RegisterMessage(GetPublicDatasetResponse)

DownloadPublicDatasetRequest = _reflection.GeneratedProtocolMessageType('DownloadPublicDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPUBLICDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetRequest)
  })
_sym_db.RegisterMessage(DownloadPublicDatasetRequest)

DownloadPublicDatasetResponse = _reflection.GeneratedProtocolMessageType('DownloadPublicDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADPUBLICDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.DownloadPublicDatasetResponse)
  })
_sym_db.RegisterMessage(DownloadPublicDatasetResponse)

PreviewPublicDatasetRequest = _reflection.GeneratedProtocolMessageType('PreviewPublicDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWPUBLICDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetRequest)
  })
_sym_db.RegisterMessage(PreviewPublicDatasetRequest)

PreviewPublicDatasetResponse = _reflection.GeneratedProtocolMessageType('PreviewPublicDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREVIEWPUBLICDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.PreviewPublicDatasetResponse)
  })
_sym_db.RegisterMessage(PreviewPublicDatasetResponse)

ApplyPublicDatasetCRRequest = _reflection.GeneratedProtocolMessageType('ApplyPublicDatasetCRRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPUBLICDATASETCRREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRRequest)
  })
_sym_db.RegisterMessage(ApplyPublicDatasetCRRequest)

ApplyPublicDatasetCRResponse = _reflection.GeneratedProtocolMessageType('ApplyPublicDatasetCRResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYPUBLICDATASETCRRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ApplyPublicDatasetCRResponse)
  })
_sym_db.RegisterMessage(ApplyPublicDatasetCRResponse)

ListPretrainedModelsRequest = _reflection.GeneratedProtocolMessageType('ListPretrainedModelsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTPRETRAINEDMODELSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTPRETRAINEDMODELSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsRequest)
  })
_sym_db.RegisterMessage(ListPretrainedModelsRequest)
_sym_db.RegisterMessage(ListPretrainedModelsRequest.LabelsEntry)

ListPretrainedModelsResponse = _reflection.GeneratedProtocolMessageType('ListPretrainedModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPRETRAINEDMODELSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListPretrainedModelsResponse)
  })
_sym_db.RegisterMessage(ListPretrainedModelsResponse)

GetPretrainedModelRequest = _reflection.GeneratedProtocolMessageType('GetPretrainedModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPRETRAINEDMODELREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelRequest)
  })
_sym_db.RegisterMessage(GetPretrainedModelRequest)

GetPretrainedModelResponse = _reflection.GeneratedProtocolMessageType('GetPretrainedModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETPRETRAINEDMODELRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetPretrainedModelResponse)
  })
_sym_db.RegisterMessage(GetPretrainedModelResponse)

ListWorkloadClassesRequest = _reflection.GeneratedProtocolMessageType('ListWorkloadClassesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWORKLOADCLASSESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWORKLOADCLASSESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesRequest)
  })
_sym_db.RegisterMessage(ListWorkloadClassesRequest)
_sym_db.RegisterMessage(ListWorkloadClassesRequest.LabelsEntry)

ListWorkloadClassesResponse = _reflection.GeneratedProtocolMessageType('ListWorkloadClassesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWORKLOADCLASSESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.ListWorkloadClassesResponse)
  })
_sym_db.RegisterMessage(ListWorkloadClassesResponse)

GetWorkloadClassRequest = _reflection.GeneratedProtocolMessageType('GetWorkloadClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKLOADCLASSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassRequest)
  })
_sym_db.RegisterMessage(GetWorkloadClassRequest)

GetWorkloadClassResponse = _reflection.GeneratedProtocolMessageType('GetWorkloadClassResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWORKLOADCLASSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.catalog.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.catalog.v1.GetWorkloadClassResponse)
  })
_sym_db.RegisterMessage(GetWorkloadClassResponse)

_CATALOGSERVICE = DESCRIPTOR.services_by_name['CatalogService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/catalog/v1'
  _LISTALGORITHMSREQUEST_LABELSENTRY._options = None
  _LISTALGORITHMSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTMANAGEDIMAGESREQUEST_LABELSENTRY._options = None
  _LISTMANAGEDIMAGESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTMLFRAMEWORKSREQUEST_LABELSENTRY._options = None
  _LISTMLFRAMEWORKSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTCLOUDSREQUEST_LABELSENTRY._options = None
  _LISTCLOUDSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTPUBLICDATASETSREQUEST_LABELSENTRY._options = None
  _LISTPUBLICDATASETSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTPRETRAINEDMODELSREQUEST_LABELSENTRY._options = None
  _LISTPRETRAINEDMODELSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LISTWORKLOADCLASSESREQUEST_LABELSENTRY._options = None
  _LISTWORKLOADCLASSESREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CATALOGSERVICE.methods_by_name['ListAlgorithm']._options = None
  _CATALOGSERVICE.methods_by_name['ListAlgorithm']._serialized_options = b'\202\323\344\223\002\020\022\016/v1/algorithms'
  _CATALOGSERVICE.methods_by_name['GetAlgorithm']._options = None
  _CATALOGSERVICE.methods_by_name['GetAlgorithm']._serialized_options = b'\202\323\344\223\002\027\022\025/v1/algorithms/{name}'
  _CATALOGSERVICE.methods_by_name['ListManagedImages']._options = None
  _CATALOGSERVICE.methods_by_name['ListManagedImages']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/managedimages'
  _CATALOGSERVICE.methods_by_name['GetManagedImage']._options = None
  _CATALOGSERVICE.methods_by_name['GetManagedImage']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/managedimages/{name}'
  _CATALOGSERVICE.methods_by_name['ListMLFrameworks']._options = None
  _CATALOGSERVICE.methods_by_name['ListMLFrameworks']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/mlframeworks'
  _CATALOGSERVICE.methods_by_name['GetMLFramework']._options = None
  _CATALOGSERVICE.methods_by_name['GetMLFramework']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/mlframeworks/{name}'
  _CATALOGSERVICE.methods_by_name['ListClouds']._options = None
  _CATALOGSERVICE.methods_by_name['ListClouds']._serialized_options = b'\202\323\344\223\002\014\022\n/v1/clouds'
  _CATALOGSERVICE.methods_by_name['GetCloud']._options = None
  _CATALOGSERVICE.methods_by_name['GetCloud']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/clouds/{name}'
  _CATALOGSERVICE.methods_by_name['ListWorkloadClasses']._options = None
  _CATALOGSERVICE.methods_by_name['ListWorkloadClasses']._serialized_options = b'\202\323\344\223\002\025\022\023/v1/workloadclasses'
  _CATALOGSERVICE.methods_by_name['GetWorkloadClass']._options = None
  _CATALOGSERVICE.methods_by_name['GetWorkloadClass']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/workloadclasses/{name}'
  _CATALOGSERVICE.methods_by_name['ListPublicDataset']._options = None
  _CATALOGSERVICE.methods_by_name['ListPublicDataset']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/publicdatasets'
  _CATALOGSERVICE.methods_by_name['GetPublicDataset']._options = None
  _CATALOGSERVICE.methods_by_name['GetPublicDataset']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/publicdatasets/{name}'
  _CATALOGSERVICE.methods_by_name['DownloadPublicDataset']._options = None
  _CATALOGSERVICE.methods_by_name['DownloadPublicDataset']._serialized_options = b'\202\323\344\223\002$\022\"/v1/publicdatasets/{name}:download'
  _CATALOGSERVICE.methods_by_name['PreviewPublicDataset']._options = None
  _CATALOGSERVICE.methods_by_name['PreviewPublicDataset']._serialized_options = b'\202\323\344\223\002#\022!/v1/publicdatasets/{name}:preview'
  _CATALOGSERVICE.methods_by_name['ApplyPublicDatasetCR']._options = None
  _CATALOGSERVICE.methods_by_name['ApplyPublicDatasetCR']._serialized_options = b'\202\323\344\223\002!\022\037/v1/publicdatasets/{name}:apply'
  _LISTALGORITHMSREQUEST._serialized_start=256
  _LISTALGORITHMSREQUEST._serialized_end=447
  _LISTALGORITHMSREQUEST_LABELSENTRY._serialized_start=402
  _LISTALGORITHMSREQUEST_LABELSENTRY._serialized_end=447
  _LISTALGORITHMSRESPONSE._serialized_start=449
  _LISTALGORITHMSRESPONSE._serialized_end=565
  _GETALGORITHMREQUEST._serialized_start=567
  _GETALGORITHMREQUEST._serialized_end=621
  _GETALGORITHMRESPONSE._serialized_start=623
  _GETALGORITHMRESPONSE._serialized_end=732
  _LISTMANAGEDIMAGESREQUEST._serialized_start=735
  _LISTMANAGEDIMAGESREQUEST._serialized_end=932
  _LISTMANAGEDIMAGESREQUEST_LABELSENTRY._serialized_start=402
  _LISTMANAGEDIMAGESREQUEST_LABELSENTRY._serialized_end=447
  _LISTMANAGEDIMAGESRESPONSE._serialized_start=934
  _LISTMANAGEDIMAGESRESPONSE._serialized_end=1059
  _GETMANAGEDIMAGEREQUEST._serialized_start=1061
  _GETMANAGEDIMAGEREQUEST._serialized_end=1118
  _GETMANAGEDIMAGERESPONSE._serialized_start=1120
  _GETMANAGEDIMAGERESPONSE._serialized_end=1237
  _LISTMLFRAMEWORKSREQUEST._serialized_start=1240
  _LISTMLFRAMEWORKSREQUEST._serialized_end=1435
  _LISTMLFRAMEWORKSREQUEST_LABELSENTRY._serialized_start=402
  _LISTMLFRAMEWORKSREQUEST_LABELSENTRY._serialized_end=447
  _LISTMLFRAMEWORKSRESPONSE._serialized_start=1437
  _LISTMLFRAMEWORKSRESPONSE._serialized_end=1559
  _GETMLFRAMEWORKREQUEST._serialized_start=1561
  _GETMLFRAMEWORKREQUEST._serialized_end=1617
  _GETMLFRAMEWORKRESPONSE._serialized_start=1619
  _GETMLFRAMEWORKRESPONSE._serialized_end=1734
  _LISTCLOUDSREQUEST._serialized_start=1737
  _LISTCLOUDSREQUEST._serialized_end=1920
  _LISTCLOUDSREQUEST_LABELSENTRY._serialized_start=402
  _LISTCLOUDSREQUEST_LABELSENTRY._serialized_end=447
  _LISTCLOUDSRESPONSE._serialized_start=1922
  _LISTCLOUDSRESPONSE._serialized_end=2026
  _GETCLOUDREQUEST._serialized_start=2028
  _GETCLOUDREQUEST._serialized_end=2078
  _GETCLOUDRESPONSE._serialized_start=2080
  _GETCLOUDRESPONSE._serialized_end=2177
  _LISTPUBLICDATASETSREQUEST._serialized_start=2180
  _LISTPUBLICDATASETSREQUEST._serialized_end=2379
  _LISTPUBLICDATASETSREQUEST_LABELSENTRY._serialized_start=402
  _LISTPUBLICDATASETSREQUEST_LABELSENTRY._serialized_end=447
  _LISTPUBLICDATASETSRESPONSE._serialized_start=2382
  _LISTPUBLICDATASETSRESPONSE._serialized_end=2510
  _GETPUBLICDATASETREQUEST._serialized_start=2512
  _GETPUBLICDATASETREQUEST._serialized_end=2570
  _GETPUBLICDATASETRESPONSE._serialized_start=2572
  _GETPUBLICDATASETRESPONSE._serialized_end=2693
  _DOWNLOADPUBLICDATASETREQUEST._serialized_start=2695
  _DOWNLOADPUBLICDATASETREQUEST._serialized_end=2758
  _DOWNLOADPUBLICDATASETRESPONSE._serialized_start=2760
  _DOWNLOADPUBLICDATASETRESPONSE._serialized_end=2804
  _PREVIEWPUBLICDATASETREQUEST._serialized_start=2806
  _PREVIEWPUBLICDATASETREQUEST._serialized_end=2868
  _PREVIEWPUBLICDATASETRESPONSE._serialized_start=2870
  _PREVIEWPUBLICDATASETRESPONSE._serialized_end=2913
  _APPLYPUBLICDATASETCRREQUEST._serialized_start=2915
  _APPLYPUBLICDATASETCRREQUEST._serialized_end=2993
  _APPLYPUBLICDATASETCRRESPONSE._serialized_start=2995
  _APPLYPUBLICDATASETCRRESPONSE._serialized_end=3038
  _LISTPRETRAINEDMODELSREQUEST._serialized_start=3041
  _LISTPRETRAINEDMODELSREQUEST._serialized_end=3244
  _LISTPRETRAINEDMODELSREQUEST_LABELSENTRY._serialized_start=402
  _LISTPRETRAINEDMODELSREQUEST_LABELSENTRY._serialized_end=447
  _LISTPRETRAINEDMODELSRESPONSE._serialized_start=3247
  _LISTPRETRAINEDMODELSRESPONSE._serialized_end=3381
  _GETPRETRAINEDMODELREQUEST._serialized_start=3383
  _GETPRETRAINEDMODELREQUEST._serialized_end=3443
  _GETPRETRAINEDMODELRESPONSE._serialized_start=3445
  _GETPRETRAINEDMODELRESPONSE._serialized_end=3572
  _LISTWORKLOADCLASSESREQUEST._serialized_start=3575
  _LISTWORKLOADCLASSESREQUEST._serialized_end=3776
  _LISTWORKLOADCLASSESREQUEST_LABELSENTRY._serialized_start=402
  _LISTWORKLOADCLASSESREQUEST_LABELSENTRY._serialized_end=447
  _LISTWORKLOADCLASSESRESPONSE._serialized_start=3778
  _LISTWORKLOADCLASSESRESPONSE._serialized_end=3902
  _GETWORKLOADCLASSREQUEST._serialized_start=3904
  _GETWORKLOADCLASSREQUEST._serialized_end=3962
  _GETWORKLOADCLASSRESPONSE._serialized_start=3964
  _GETWORKLOADCLASSRESPONSE._serialized_end=4080
  _CATALOGSERVICE._serialized_start=4083
  _CATALOGSERVICE._serialized_end=7173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/batchpredictord/v1/batchpredictord.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_inference_dot_v1alpha1_dot_generated__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOgithub.com/metaprov/modelaapi/services/batchpredictord/v1/batchpredictord.proto\x12\x39github.com.metaprov.modelaapi.services.batchpredictord.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1aIgithub.com/metaprov/modelaapi/pkg/apis/inference/v1alpha1/generated.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xa2\x06\n\x13\x42\x61tchPredictRequest\x12Y\n\nprediction\x18\x01 \x01(\x0b\x32\x45.github.com.metaprov.modelaapi.pkg.apis.inference.v1alpha1.Prediction\x12X\n\nfromBucket\x18\x02 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12Y\n\x0e\x66romConnection\x18\x03 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12r\n\nfromSecret\x18\x04 \x03(\x0b\x32^.github.com.metaprov.modelaapi.services.batchpredictord.v1.BatchPredictRequest.FromSecretEntry\x12Z\n\x0ctargetBucket\x18\x05 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.VirtualBucket\x12W\n\x0ctoConnection\x18\x06 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12n\n\x08toSecret\x18\x07 \x03(\x0b\x32\\.github.com.metaprov.modelaapi.services.batchpredictord.v1.BatchPredictRequest.ToSecretEntry\x1a\x31\n\x0f\x46romSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rToSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x16\n\x14\x42\x61tchPredictResponse2\xf9\x01\n\x05\x42\x61tch\x12\xb1\x01\n\x0c\x42\x61tchPredict\x12N.github.com.metaprov.modelaapi.services.batchpredictord.v1.BatchPredictRequest\x1aO.github.com.metaprov.modelaapi.services.batchpredictord.v1.BatchPredictResponse\"\x00\x12<\n\x08Shutdown\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x42;Z9github.com/metaprov/modelaapi/services/batchpredictord/v1b\x06proto3')



_BATCHPREDICTREQUEST = DESCRIPTOR.message_types_by_name['BatchPredictRequest']
_BATCHPREDICTREQUEST_FROMSECRETENTRY = _BATCHPREDICTREQUEST.nested_types_by_name['FromSecretEntry']
_BATCHPREDICTREQUEST_TOSECRETENTRY = _BATCHPREDICTREQUEST.nested_types_by_name['ToSecretEntry']
_BATCHPREDICTRESPONSE = DESCRIPTOR.message_types_by_name['BatchPredictResponse']
BatchPredictRequest = _reflection.GeneratedProtocolMessageType('BatchPredictRequest', (_message.Message,), {

  'FromSecretEntry' : _reflection.GeneratedProtocolMessageType('FromSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _BATCHPREDICTREQUEST_FROMSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.batchpredictord.v1.batchpredictord_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.batchpredictord.v1.BatchPredictRequest.FromSecretEntry)
    })
  ,

  'ToSecretEntry' : _reflection.GeneratedProtocolMessageType('ToSecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _BATCHPREDICTREQUEST_TOSECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.batchpredictord.v1.batchpredictord_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.batchpredictord.v1.BatchPredictRequest.ToSecretEntry)
    })
  ,
  'DESCRIPTOR' : _BATCHPREDICTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.batchpredictord.v1.batchpredictord_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.batchpredictord.v1.BatchPredictRequest)
  })
_sym_db.RegisterMessage(BatchPredictRequest)
_sym_db.RegisterMessage(BatchPredictRequest.FromSecretEntry)
_sym_db.RegisterMessage(BatchPredictRequest.ToSecretEntry)

BatchPredictResponse = _reflection.GeneratedProtocolMessageType('BatchPredictResponse', (_message.Message,), {
  'DESCRIPTOR' : _BATCHPREDICTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.batchpredictord.v1.batchpredictord_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.batchpredictord.v1.BatchPredictResponse)
  })
_sym_db.RegisterMessage(BatchPredictResponse)

_BATCH = DESCRIPTOR.services_by_name['Batch']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z9github.com/metaprov/modelaapi/services/batchpredictord/v1'
  _BATCHPREDICTREQUEST_FROMSECRETENTRY._options = None
  _BATCHPREDICTREQUEST_FROMSECRETENTRY._serialized_options = b'8\001'
  _BATCHPREDICTREQUEST_TOSECRETENTRY._options = None
  _BATCHPREDICTREQUEST_TOSECRETENTRY._serialized_options = b'8\001'
  _BATCHPREDICTREQUEST._serialized_start=318
  _BATCHPREDICTREQUEST._serialized_end=1120
  _BATCHPREDICTREQUEST_FROMSECRETENTRY._serialized_start=1022
  _BATCHPREDICTREQUEST_FROMSECRETENTRY._serialized_end=1071
  _BATCHPREDICTREQUEST_TOSECRETENTRY._serialized_start=1073
  _BATCHPREDICTREQUEST_TOSECRETENTRY._serialized_end=1120
  _BATCHPREDICTRESPONSE._serialized_start=1122
  _BATCHPREDICTRESPONSE._serialized_end=1144
  _BATCH._serialized_start=1147
  _BATCH._serialized_end=1396
# @@protoc_insertion_point(module_scope)
